@@ -94,6 +94,8 @@ static const QString styleSheetMenu =
 
 #endif
 
+QTM_USE_NAMESPACE
+
 CCanvas::CCanvas()
 : largeIcons(false)
 , initialized(false)
@@ -213,13 +215,6 @@ CCanvas::CCanvas()
 #endif
 
     largeIcons = cfg.value("environment/largeIcons", largeIcons).toBool();
-#ifdef NOKIA
-     QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                      MCE_DEVICE_ORIENTATION_SIG,
-                      this,
-                      SLOT(orientationChanged(QString)));
-#endif
-    
     qApp->installEventFilter(this);
 }
 
@@ -257,18 +252,6 @@ bool CCanvas::eventFilter(QObject *obj, QEvent *ev)
             }
         }
     }
-    if (ev->type() == QEvent::WindowActivate) {
-	    QDBusConnection::systemBus().call(
-	    		    QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-			    	    MCE_REQUEST_IF,
-			            MCE_ACCELEROMETER_ENABLE_REQ));
-    }
-    if (ev->type() == QEvent::WindowDeactivate) {
-	    QDBusConnection::systemBus().call(
-			    QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-				    MCE_REQUEST_IF,
-				    MCE_ACCELEROMETER_DISABLE_REQ));
-    }
     return QWidget::eventFilter(obj,ev);
 }
 
@@ -713,16 +696,3 @@ int CCanvas::getCurrentPos(qreal& x, qreal& y, qreal &ele)
         return CCanvas::eLocked;
     }
 }
-
-
-void CCanvas::orientationChanged(const QString &newOrientation)
-{
-	if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT)) {
-		setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-		setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
-	}
-	else {
-		setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-		setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
-	}
-}
